#
# spec file for package spotifyd
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define spotifyd_features alsa_backend,dbus_keyring,dbus_mpris,pulseaudio_backend
Name:           spotifyd
Version:        0.3.5
Release:        1.1
Summary:        Spotify client running as a UNIX daemon
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Sound/Players
URL:            https://spotifyd.rs/
Source0:        %{name}-%{version}.tar.xz
Source1:        vendor.tar.xz
Source2:        cargo_config
BuildRequires:  cargo
BuildRequires:  cargo-packaging
BuildRequires:  rinstall
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(avahi-client)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(openssl)

%description
Spotifyd streams music just like the official client, but is more lightweight
and supports more platforms. Spotifyd also supports the Spotify Connect
protocol, which makes it show up as a device that can be controlled from
the official clients.

%prep
%autosetup -a1
mkdir .cargo
cp %{SOURCE2} .cargo/config

%build
%{cargo_build} --features %{spotifyd_features}

%install
install -pm0755 -D target/release/spotifyd %{buildroot}%{_bindir}/spotifyd
install -pm0644 -D contrib/spotifyd.service %{buildroot}%{_userunitdir}/spotifyd.service

%pre
%service_add_pre spotifyd.service

%post
%service_add_post spotifyd.service

%preun
%service_del_preun spotifyd.service

%postun
%service_del_postun spotifyd.service

%files
%license LICENSE
%doc CHANGELOG.md README.md
%{_userunitdir}/spotifyd.service
%{_bindir}/spotifyd

%changelog
* Mon Nov  6 2023 mailaender@opensuse.org
- Update to version 0.3.5:
  * new project website
  * Credential caching has been re-enabled
  * A audio_format option was added to circumvent certain errors
  * Improved backend selection logic
  * Documentation improvements
  * Minimum supported rust version (MSRV) has been bumped to 1.64
  * Dependency updated
  * Shuffle setter.
- Update to version 0.3.4:
  * Add cache_size configuration option
  * Add dbus_type configuration option
  * Improve error reporting
  * Fix wrong handling of credential cache
* Tue Feb 14 2023 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Thu Aug  4 2022 William Brown <william.brown@suse.com>
- bsc#1182059 - CVE-2021-21299 - hyper request smuggling
* Mon Jun 20 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Tue May 24 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Tue Apr  5 2022 William Brown <william.brown@suse.com>
- Automatic update of vendored dependencies
* Mon Mar 14 2022 William Brown <william.brown@suse.com>
- Update to resolve bsc#1196972 CVE-2022-24713 - Regex DOS
* Tue Feb 15 2022 William Brown <william.brown@suse.com>
- Update vendor.tar to resolve:
  * RUSTSEC-2020-0006 bumpalo, cvss: CVSS:3.1/AV:N/AC:L/PR:N/UI:N/S:U/C:H/I:N/A:N, class: ['memory-exposure']
  * RUSTSEC-2021-0020 hyper, cvss: CVSS:3.1/AV:N/AC:H/PR:N/UI:N/S:U/C:H/I:H/A:H, class: ['format-injection']
  * RUSTSEC-2021-0078 hyper, cvss: CVSS:3.1/AV:N/AC:L/PR:N/UI:N/S:U/C:N/I:L/A:N, class: []
  * RUSTSEC-2021-0079 hyper, cvss: CVSS:3.1/AV:N/AC:L/PR:N/UI:N/S:U/C:N/I:H/A:H, class: []
  * RUSTSEC-2021-0078 hyper, cvss: CVSS:3.1/AV:N/AC:L/PR:N/UI:N/S:U/C:N/I:L/A:N, class: []
  * RUSTSEC-2021-0079 hyper, cvss: CVSS:3.1/AV:N/AC:L/PR:N/UI:N/S:U/C:N/I:H/A:H, class: []
  * RUSTSEC-2021-0119 nix, cvss: None, class: ['memory-corruption']
  * RUSTSEC-2021-0003 smallvec, cvss: CVSS:3.1/AV:N/AC:L/PR:N/UI:N/S:U/C:H/I:H/A:H, class: ['memory-corruption']
  * RUSTSEC-2021-0124 tokio, cvss: None, class: ['memory-corruption', 'thread-safety']
  * RUSTSEC-2021-0124 tokio, cvss: None, class: ['memory-corruption', 'thread-safety']
* Wed Jan 19 2022 Matthias Mailänder <mailaender@opensuse.org>
- Remove harden_spotifyd.service.patch (bsc#1194800)
* Thu Jan  6 2022 william.brown@suse.com
- resolve bsc#1194119 (CVE-2021-45710)
* Tue Dec 14 2021 danilo.spinella@suse.com
- Update to version 0.3.3:
  * Bump version: 0.3.2 -> 0.3.3
  * One last clippy warning
  * More clippy errors
  * Fix a first round of lint checks
  * Run rustfmt to pass lint check
  * Switch to not importing librespot root (which is binary) in favour of smaller libraries
  * docs: Minor comment additions for MacOS
  * Fix normalization.
  * Fix polling in DBUS init
- Update spec file to use cargo-packaging
* Tue Nov 23 2021 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Added patch(es):
  * harden_spotifyd.service.patch
* Fri Nov  5 2021 William Brown <william.brown@suse.com>
- Add cargo audit service to detect potential security issues
* Sat Jun 26 2021 Jens K. <karatek@karatek.net>
- Move location of the unit file to %%{_prefix}/lib/systemd/user so that users can
  start the daemon. This is officially the recommended place to put this.
* Sun Jun 20 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Set features flag also on install step (or optinal features would
  be skipped)
* Tue May 18 2021 Matthias Mailänder <mailaender@opensuse.org>
- initial packaging of version 0.3.2
